/*
 *      (c) Copyright 1990 Sun Microsystems, Inc. Sun design patents
 *      pending in the U.S. and foreign countries. See LEGAL_NOTICE
 *      file for terms of the license.
 */

#ifdef IDENT
#ident	"@(#)defaults.h	1.3 olvwm version 12/7/92"
#endif

/*
 * Based on
#ident	"@(#)defaults.h	26.7	91/09/14 SMI"
 *
 */

/* 
 *	default constants 
 */
#define DEFWORKSPACECOLOR    	"#40a0c0"
#define DEFWINDOWCOLOR    	"#cccccc"
#define DEFFOREGROUNDCOLOR    	"#000000"
#define DEFBACKGROUNDCOLOR    	"#ffffff"
#define DEFBORDERCOLOR    	"#000000"

#define DEFVIRTUALFORECOLOR	"#cccccc"
#define DEFVIRTUALBACKCOLOR	"#40a0c0"
#define DEFVIRTUALFONTCOLOR	"#ffffff"
#define DEFVIRTUALGRIDCOLOR	"#ffffff"
#define DEFVIRTUALPIXMAPCOLOR	"#000000"

#define DEFAULTFONT		"9x15"

void	SetAllDBValues();
